#
# spec file for package libgsm
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name gsm
%define _version 1.0-pl22
Name:           libgsm
Version:        1.0.22
Release:        2.2
Summary:        GSM 06.10 Lossy Speech Compressor Library and Utilities
License:        ISC
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            http://www.quut.com/gsm/
Source:         http://www.quut.com/gsm/%{_name}-%{version}.tar.gz
Source2:        baselibs.conf
# This is a Debian patch file with debian chunks removed.
Patch0:         %{name}-1.0.20.patch
Patch1:         libgsm-paths.patch
Patch2:         libgsm-include.patch

%description
libgsm implements the European GSM 06.10 provisional standard for
full-rate speech transcoding, prI-ETS 300 036, which uses RPE/LTP
coding at 13 kbit/s. GSM 06.10 compresses frames of 160 13-bit
samples (8 kHz sampling rate) into 260 bits.

%package -n libgsm1
Summary:        GSM 06.10 Lossy Speech Compressor Library and Utilities
Group:          System/Libraries

%description -n libgsm1
Contains the library for a GSM speech compressor.

libgsm implements the European GSM 06.10 provisional standard for
full-rate speech transcoding, prI-ETS 300 036, which uses RPE/LTP
(residual pulse excitation/long term prediction) coding at 13 kbit/s.
GSM 06.10 compresses frames of 160 13-bit samples (8 kHz sampling
rate) into 260 bits.

%package utils
Summary:        GSM 06.10 Lossy Speech Compressor Library and Utilities
Group:          Productivity/Multimedia/Sound/Editors and Convertors

%description utils
Contains binaries for a GSM speech compressor, verified against the
ETSI standard test patterns.

libgsm implements the European GSM 06.10 provisional standard for
full-rate speech transcoding, prI-ETS 300 036, which uses RPE/LTP
(residual pulse excitation/long term prediction) coding at 13 kbit/s.
GSM 06.10 compresses frames of 160 13-bit samples (8 kHz sampling
rate) into 260 bits.

The front-end is modeled after the historic compress(1) utility.

%package devel
Summary:        GSM 06.10 Lossy Speech Compressor Library and Utilities
Group:          Development/Libraries/C and C++
Requires:       libgsm1 = %{version}-%{release}

%description devel
Contains the development kit for the libgsm speech compressor.

libgsm implements the European GSM 06.10 provisional standard for
full-rate speech transcoding, prI-ETS 300 036, which uses RPE/LTP
coding at 13 kbit/s. GSM 06.10 compresses frames of 160 13-bit
samples (8 kHz sampling rate) into 260 bits.

This implementation turns frames of 160 16-bit linear samples into
33-byte frames (1650 bytes/s) and has been verified against the ETSI
standard test patterns.

%prep
%setup -q -n %{_name}-%{_version}
%patch -P 0 -p1
%patch -P 1
%patch -P 2

%build
make -j1 CCFLAGS="-c %{optflags} -D_POSIX_SOURCE -D_BSD_SOURCE -DNeedFunctionPrototypes=1" lib/libgsm.a
cp lib/libgsm.a lib/libgsm.a.save
make -j1 clean
make -j1 CCFLAGS="-c %{optflags} -D_POSIX_SOURCE -D_BSD_SOURCE -DNeedFunctionPrototypes=1 -fPIC"
cp lib/libgsm.a.save lib/libgsm.a
touch lib/libgsm.a

%install
mkdir -p %{buildroot}%{_prefix}/{include/gsm,%{_lib},bin,share/man/man{1,3}}
make INSTALL_ROOT=%{buildroot}%{_prefix} GSM_INSTALL_LIB=%{buildroot}%{_libdir} install
cp -d lib/libgsm.so* %{buildroot}%{_libdir}
( cd %{buildroot}%{_libdir} ; ln -sf libgsm.so.1 libgsm.so )
cp inc/{private.h,proto.h,unproto.h} %{buildroot}%{_includedir}/gsm/
rm -f %{buildroot}%{_libdir}/*.a
ln -fsv toast %{buildroot}/%{_bindir}/untoast
ln -fsv toast %{buildroot}/%{_bindir}/tcat

%post -n libgsm1 -p /sbin/ldconfig
%postun -n libgsm1 -p /sbin/ldconfig

%files utils
%{_bindir}/*
%{_mandir}/man1/*.*

%files -n libgsm1
%license COPYRIGHT
%{_libdir}/*.so.*

%files devel
%doc ChangeLog MACHINES README
%{_libdir}/*.so
%{_mandir}/man3/*.*
%{_includedir}/gsm

%changelog
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Sun Aug 28 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.22
  * Build system updates only
- Move documentation out of libgsm1, no one reads it if it's
  implicitly installed for something else.
* Tue Jul 26 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.0.20:
  * Use $(RMFLAGS) with the rms in the Makefile; add -f to $(RMFLAGS) to
    avoid spurious error messages during build.
- Rebase and rename libgsm-1.0.20.patch from libgsm-1.0.13.patch.
- Rebase libgsm-include.patch.
* Thu Apr 29 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.19:
  * Make it easier to include gsm.h from C++ by wrapping it with macros.
    Throw a #define _POSIX_C_SOURCE 200809L into toast.h to make it
    possible for Linux glibc to just work.
  * Switch from compress/.Z to gzip/.gz
* Wed Aug 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Small cleanups with spec-cleaner
* Sat Feb 23 2019 bjorn.lie@gmail.com
- Update to version 1.0.18
  * Remove the MacOS "quarantine" files that I didn't know I'd
    shipped.
  * Remove some trailing spaces.
  * Bump up the patchlevel in inc/gsm.h (I'd forgotten that in
    release 17.)
- Changes from version 1.0.17
  * New email addresses in the README.
  * Avoid left-shifting signed integers.
  * Don't print longwords using %%d or %%ld, cast them to (long)
    first.
  * Don't compare longwords as longs in addtest, we only care for
    the lower 32 bits. (The math works, but the test failed).
- Changes from version 1.0.16
  * New email addresses in the manual pages (patch 16).
  * Removed a stray .orig file (in patch 15).
- Rebase libgsm-1.0.13.patch.
- Drop libgsm-strict-aliasing.patch: Applied upstream.
- Drop ancient Obsoletes/Provides.
* Sat Nov  7 2015 jengelh@inai.de
- Make description more concise. SPARCstations are no longer a
  meaningful metric.
* Sat Oct 10 2015 p.drouand@gmail.com
- Update to version 1.0.14
  * No changelog available
- Update libgsm-1.0.13.patch
- Use download Url as source
- Remove depreciated AUTHORS and clean sections
* Tue Aug 20 2013 mardnh@gmx.de
- fix URL (see http://www.quut.com/gsm/)
* Mon Aug 20 2012 cfarrell@suse.com
- license update: ISC
  [#]License is more akin to ISC (see http://www.spdx.org/licenses/ISC) than
  to BSD-3-Clause
* Fri Sep 23 2011 meissner@suse.de
- remove libgsm-32bit from requires
* Fri Sep 23 2011 meissner@suse.de
- add 32bit development headers for 32bit Wine on 64bit builds
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Mon Aug 10 2009 meissner@suse.de
- added baselibs.conf, libgsm is now used by wine
* Thu Aug  6 2009 sbrabec@suse.cz
- Updated to version 1.0.13:
  * cleaner wording of copyright
* Sat Apr  4 2009 crrodriguez@suse.de
- remove static libraries
* Fri Feb 22 2008 sbrabec@suse.cz
- Added Provides, Obsoletes and split-provides for old names.
* Mon Jan 28 2008 sbrabec@suse.cz
- Updated to version 1.0.12:
  * removed modifiable static storage that made the library
    non-reentrant.
  * fix WAV49 implode move source archive location
- Split package according to shared library packaging policy.
* Tue Aug  8 2006 sbrabec@suse.cz
- Compile with WAV-style framing support.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 sbrabec@suse.cz
- New SuSE package, version 1.0.10.
